@@ -1,6 +1,5 @@
 // ascii plain text
 // Licence: Lesser GNU Public License 2.1 (LGPL)
-// $Id: text.h 742 2012-07-14 00:07:22Z wojdyr $
 
 // Multi-column ascii text file.
 // In each line, we try to read as many numbers as possible.
@@ -27,7 +26,9 @@ namespace xylib {
     class TextDataSet : public DataSet
     {
         OBLIGATORY_DATASET_MEMBERS(TextDataSet)
-        virtual bool is_valid_option(std::string const& t);
+    private:
+        void load_data_with_delim(std::istream &f, char line_delim,
+                                  std::string& buf);
     };
 
 } // namespace
